"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Stream(google.protobuf.message.Message):
    """//////////////////////////////////////////////////////////////////////"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_FIELD_NUMBER: builtins.int
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Event]: ...
    def __init__(
        self,
        *,
        events: collections.abc.Iterable[global___Event] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["events", b"events"]) -> None: ...

global___Stream = Stream

@typing_extensions.final
class Event(google.protobuf.message.Message):
    """//////////////////////////////////////////////////////////////////////"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    MESSAGE_BYTES_FIELD_NUMBER: builtins.int
    id: builtins.str
    message_bytes: builtins.bytes
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        message_bytes: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "message_bytes", b"message_bytes"]) -> None: ...

global___Event = Event

@typing_extensions.final
class PutRequest(google.protobuf.message.Message):
    """//////////////////////////////////////////////////////////////////////"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    MESSAGE_BYTES_FIELD_NUMBER: builtins.int
    event_id: builtins.str
    message_bytes: builtins.bytes
    def __init__(
        self,
        *,
        event_id: builtins.str = ...,
        message_bytes: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_id", b"event_id", "message_bytes", b"message_bytes"]) -> None: ...

global___PutRequest = PutRequest

@typing_extensions.final
class PutResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PutResponse = PutResponse

@typing_extensions.final
class ReplayRequest(google.protobuf.message.Message):
    """//////////////////////////////////////////////////////////////////////"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_EVENT_ID_FIELD_NUMBER: builtins.int
    last_event_id: builtins.str
    def __init__(
        self,
        *,
        last_event_id: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_last_event_id", b"_last_event_id", "last_event_id", b"last_event_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_last_event_id", b"_last_event_id", "last_event_id", b"last_event_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_last_event_id", b"_last_event_id"]) -> typing_extensions.Literal["last_event_id"] | None: ...

global___ReplayRequest = ReplayRequest

@typing_extensions.final
class ReplayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_FIELD_NUMBER: builtins.int
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Event]: ...
    def __init__(
        self,
        *,
        events: collections.abc.Iterable[global___Event] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["events", b"events"]) -> None: ...

global___ReplayResponse = ReplayResponse
