# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rbt/mcp/v1/session.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rbt.v1alpha1 import options_pb2 as rbt_dot_v1alpha1_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18rbt/mcp/v1/session.proto\x12\nrbt.mcp.v1\x1a\x1arbt/v1alpha1/options.proto\"\x0f\n\x07Session:\x04\x82\xb5\x18\x00\";\n\x14HandleMessageRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x15\n\rmessage_bytes\x18\x02 \x01(\x0c\"\x17\n\x15HandleMessageResponse\"1\n\nRunRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x15\n\rmessage_bytes\x18\x02 \x01(\x0c\"\r\n\x0bRunResponse2\xae\x01\n\x0eSessionMethods\x12\\\n\rHandleMessage\x12 .rbt.mcp.v1.HandleMessageRequest\x1a!.rbt.mcp.v1.HandleMessageResponse\"\x06\x82\xb5\x18\x02\"\x00\x12>\n\x03Run\x12\x16.rbt.mcp.v1.RunRequest\x1a\x17.rbt.mcp.v1.RunResponse\"\x06\x82\xb5\x18\x02\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rbt.mcp.v1.session_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SESSION']._loaded_options = None
  _globals['_SESSION']._serialized_options = b'\202\265\030\000'
  _globals['_SESSIONMETHODS'].methods_by_name['HandleMessage']._loaded_options = None
  _globals['_SESSIONMETHODS'].methods_by_name['HandleMessage']._serialized_options = b'\202\265\030\002\"\000'
  _globals['_SESSIONMETHODS'].methods_by_name['Run']._loaded_options = None
  _globals['_SESSIONMETHODS'].methods_by_name['Run']._serialized_options = b'\202\265\030\002\"\000'
  _globals['_SESSION']._serialized_start=68
  _globals['_SESSION']._serialized_end=83
  _globals['_HANDLEMESSAGEREQUEST']._serialized_start=85
  _globals['_HANDLEMESSAGEREQUEST']._serialized_end=144
  _globals['_HANDLEMESSAGERESPONSE']._serialized_start=146
  _globals['_HANDLEMESSAGERESPONSE']._serialized_end=169
  _globals['_RUNREQUEST']._serialized_start=171
  _globals['_RUNREQUEST']._serialized_end=220
  _globals['_RUNRESPONSE']._serialized_start=222
  _globals['_RUNRESPONSE']._serialized_end=235
  _globals['_SESSIONMETHODS']._serialized_start=238
  _globals['_SESSIONMETHODS']._serialized_end=412
# @@protoc_insertion_point(module_scope)
