# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rbt/mcp/v1/stream.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from rbt.v1alpha1 import options_pb2 as rbt_dot_v1alpha1_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17rbt/mcp/v1/stream.proto\x12\nrbt.mcp.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1arbt/v1alpha1/options.proto\"1\n\x06Stream\x12!\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x11.rbt.mcp.v1.Event:\x04\x82\xb5\x18\x00\"*\n\x05\x45vent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rmessage_bytes\x18\x02 \x01(\x0c\"5\n\nPutRequest\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\t\x12\x15\n\rmessage_bytes\x18\x02 \x01(\x0c\"\r\n\x0bPutResponse\"=\n\rReplayRequest\x12\x1a\n\rlast_event_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x10\n\x0e_last_event_id\"3\n\x0eReplayResponse\x12!\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x11.rbt.mcp.v1.Event2\xda\x01\n\rStreamMethods\x12@\n\x06\x43reate\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x06\x82\xb5\x18\x02\x12\x00\x12>\n\x03Put\x12\x16.rbt.mcp.v1.PutRequest\x1a\x17.rbt.mcp.v1.PutResponse\"\x06\x82\xb5\x18\x02\x12\x00\x12G\n\x06Replay\x12\x19.rbt.mcp.v1.ReplayRequest\x1a\x1a.rbt.mcp.v1.ReplayResponse\"\x06\x82\xb5\x18\x02\n\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rbt.mcp.v1.stream_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STREAM']._loaded_options = None
  _globals['_STREAM']._serialized_options = b'\202\265\030\000'
  _globals['_STREAMMETHODS'].methods_by_name['Create']._loaded_options = None
  _globals['_STREAMMETHODS'].methods_by_name['Create']._serialized_options = b'\202\265\030\002\022\000'
  _globals['_STREAMMETHODS'].methods_by_name['Put']._loaded_options = None
  _globals['_STREAMMETHODS'].methods_by_name['Put']._serialized_options = b'\202\265\030\002\022\000'
  _globals['_STREAMMETHODS'].methods_by_name['Replay']._loaded_options = None
  _globals['_STREAMMETHODS'].methods_by_name['Replay']._serialized_options = b'\202\265\030\002\n\000'
  _globals['_STREAM']._serialized_start=96
  _globals['_STREAM']._serialized_end=145
  _globals['_EVENT']._serialized_start=147
  _globals['_EVENT']._serialized_end=189
  _globals['_PUTREQUEST']._serialized_start=191
  _globals['_PUTREQUEST']._serialized_end=244
  _globals['_PUTRESPONSE']._serialized_start=246
  _globals['_PUTRESPONSE']._serialized_end=259
  _globals['_REPLAYREQUEST']._serialized_start=261
  _globals['_REPLAYREQUEST']._serialized_end=322
  _globals['_REPLAYRESPONSE']._serialized_start=324
  _globals['_REPLAYRESPONSE']._serialized_end=375
  _globals['_STREAMMETHODS']._serialized_start=378
  _globals['_STREAMMETHODS']._serialized_end=596
# @@protoc_insertion_point(module_scope)
